==> nui_core-0.0.28.tar.gz: lib/ui/component/nui_dialog_widget.dart <==
import 'dart:developer';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/nui_core.dart';

typedef DialogDismissCallback = void Function(Function onDismiss);
typedef DialogBuilder = Widget Function(BuildContext context);

NUIDialog showNUIDialog({@required BuildContext context, String barrierLabel, bool dismissible:true, Color barrierColor, double opacity: 0.8, @required DialogBuilder content, Alignment alignment:Alignment.center, PageTransition transition, bool useSafeArea: true, Duration transitionDuration, Function onDismiss}){
  return NUIDialog.showNUIDialog(context: context, content: content, barrierLabel: barrierLabel, dismissible: dismissible, opacity: opacity, barrierColor: barrierColor, alignment: alignment, transition: transition, useSafeArea: useSafeArea, transitionDuration: transitionDuration, onDismiss: onDismiss);
}

NUIDialog showNUIDialogByItem({@required BuildContext context, @required NUIDialogItem item}){
  return NUIDialog.showNUIDialogByItem(context: context, item: item);
}

class NUIDialogItem{
  NUIDialogItem ({
    this.barrierLabel,
    this.dismissible:true,
    this.barrierColor,
    this.opacity: 0.8,
    @required this.content,
    this.alignment:Alignment.center,
    this.transition,
    this.useSafeArea: true,
    this.transitionDuration,
    this.onDismiss});
  String barrierLabel;
  bool dismissible;
  Color barrierColor;
  double opacity;
  DialogBuilder content;
  Alignment alignment;
  PageTransition transition;
  bool useSafeArea;
  Duration transitionDuration;
  Function onDismiss;
}

class NUIDialog{
  NUIDialog._builder({@required this.content, @required this.label, @required this.dismiss});

  final DialogBuilder content;
  final String label;
  DialogDismissCallback dismiss;

  static dynamic _getTransition(BuildContext context, Widget content, {PageTransition transition, Animation animation, Animation secondaryAnimation, Widget child}){
    switch(transition){
      case PageTransition.BOTTOM_TOP : {
        var begin = Offset(0.0, 1.0);
        var end = Offset.zero;
        var curve = Curves.ease;
        var tween = Tween(begin: begin, end: end).chain(CurveTween(curve: curve));
        return SlideTransition(position: animation.drive(tween), child: child,);
      }
      case PageTransition.BLUR_BACKGROUND : {
        return BackdropFilter(
          filter: ImageFilter.blur(sigmaX: 4 * animation.value, sigmaY: 4 * animation.value),
          child: FadeTransition(
            child: child,
            opacity: animation,
          ),
        );
      }
      case PageTransition.LEFT_RIGHT : {
        return SlideTransition(
          position: Tween<Offset>(
            begin: const Offset(-1, 0),
            end: Offset.zero,
          ).animate(animation),
          child: child,
        );
      }
      case PageTransition.SCALE : {
        return ScaleTransition(
          scale: Tween<double>(begin: 0.0, end: 1.0,).animate(
            CurvedAnimation(
              parent: animation,
              curve: Curves.fastOutSlowIn,
            ),
          ),
          child: child,
        );
      }
      case PageTransition.FADE : {
        return FadeTransition(
          opacity: animation,
          child: child,
        );
      }
      default: {
        return FadeTransition(
          opacity: animation,
          child: child,
        );
      }
    }
  }

  static NUIDialog showNUIDialogByItem({@required BuildContext context, @required NUIDialogItem item}){
    return showNUIDialog(context: context, content: item.content, barrierColor: item.barrierColor, barrierLabel: item.barrierLabel, dismissible: item.dismissible, opacity: item.opacity, alignment: item.alignment, transition: item.transition, useSafeArea: item.useSafeArea, transitionDuration: item.transitionDuration, onDismiss: item.onDismiss);
  }

  static NUIDialog showNUIDialog({@required BuildContext context, String barrierLabel, bool dismissible:true, Color barrierColor, double opacity: 0.8, @required DialogBuilder content, Alignment alignment:Alignment.center, PageTransition transition, bool useSafeArea: true, Duration transitionDuration, Function onDismiss}){
    NUIDialog dialog = NUIDialog._builder(content: content, label: barrierLabel, dismiss: (Function innerDismiss){
      log("NUIDialog -> Dialog dismiss not initiated yet");
    });
    try {
      showGeneralDialog(
          barrierLabel: barrierLabel ?? "NUIDialog",
          barrierColor: barrierColor ??
              Colors.black.withOpacity(opacity ?? 0.8),
          barrierDismissible: dismissible ?? true,
          transitionDuration: transitionDuration ?? Duration(milliseconds: 250),
          context: context,
          pageBuilder: (context, animation, secondaryAnimation) {
            dialog.dismiss = (Function innerDismiss) {
              log("NUIDialog -> Dismissing dialog ... ");
              Navigator.pop(context);
              if (transitionDuration != null) {
                NUIAsync.delay(transitionDuration, () {
                  if (onDismiss != null) {
                    onDismiss();
                  }
                  innerDismiss();
                });
              }
              else {
                if (onDismiss != null) {
                  onDismiss();
                }
                innerDismiss();
              }
            };
            return Align(
              alignment: alignment ?? Alignment.center,
              child: content(context),
            );
          },
          transitionBuilder: (context, animation, secondaryAnimation, child) {
            return _getTransition(
                context, content(context), transition: transition,
                animation: animation,
                secondaryAnimation: secondaryAnimation,
                child: child);
          }
      );
    }catch(e){

    }

    return dialog;
  }
}

class NUIDialogWidget extends StatefulWidget {
  NUIDialogWidget({@required this.content, this.backgroundColor:NUIColors.NUITransparent, this.elevation:0, Key key}): super(key : key);
  final Widget content;
  final double elevation;
  final Color backgroundColor;
  @override
  _NUIDialogWidgetState createState() => _NUIDialogWidgetState();
}

class _NUIDialogWidgetState extends State<NUIDialogWidget> {
  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(0)),
      elevation: widget.elevation,
      backgroundColor: widget.backgroundColor,
      child: widget.content,
    );
  }
}

==> nui_core-0.0.64.tar.gz: lib/ui/component/nui_dialog_widget.dart <==
import 'dart:developer';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/nui_core.dart';

typedef DialogDismissCallback = void Function(Function onDismiss);
typedef DialogBuilder = Widget Function(BuildContext context);

NUIDialog showNUIDialog({@required BuildContext context, String barrierLabel, bool dismissible:true, Color barrierColor, double opacity: 0.8, @required DialogBuilder content, Alignment alignment:Alignment.center, PageTransition transition, bool useSafeArea: true, Duration transitionDuration, Function onDismiss}){
  return NUIDialog.showNUIDialog(context: context, content: content, barrierLabel: barrierLabel, dismissible: dismissible, opacity: opacity, barrierColor: barrierColor, alignment: alignment, transition: transition, useSafeArea: useSafeArea, transitionDuration: transitionDuration, onDismiss: onDismiss);
}

NUIDialog showNUIDialogByItem({@required BuildContext context, @required NUIDialogItem item}){
  return NUIDialog.showNUIDialogByItem(context: context, item: item);
}

class NUIDialogItem{
  NUIDialogItem ({
    this.barrierLabel,
    this.dismissible:true,
    this.barrierColor,
    this.opacity: 0.8,
    @required this.content,
    this.alignment:Alignment.center,
    this.transition,
    this.useSafeArea: true,
    this.transitionDuration,
    this.onDismiss});
  String barrierLabel;
  bool dismissible;
  Color barrierColor;
  double opacity;
  DialogBuilder content;
  Alignment alignment;
  PageTransition transition;
  bool useSafeArea;
  Duration transitionDuration;
  Function onDismiss;
}

class NUIDialog{
  NUIDialog._builder({@required this.content, @required this.label, @required this.dismiss});

  final DialogBuilder content;
  final String label;
  DialogDismissCallback dismiss;

  static dynamic _getTransition(BuildContext context, Widget content, {PageTransition transition, Animation animation, Animation secondaryAnimation, Widget child}){
    switch(transition){
      case PageTransition.BOTTOM_TOP : {
        var begin = Offset(0.0, 1.0);
        var end = Offset.zero;
        var curve = Curves.ease;
        var tween = Tween(begin: begin, end: end).chain(CurveTween(curve: curve));
        return SlideTransition(position: animation.drive(tween), child: child,);
      }
      case PageTransition.BLUR_BACKGROUND : {
        return BackdropFilter(
          filter: ImageFilter.blur(sigmaX: 4 * animation.value, sigmaY: 4 * animation.value),
          child: FadeTransition(
            child: child,
            opacity: animation,
          ),
        );
      }
      case PageTransition.LEFT_RIGHT : {
        return SlideTransition(
          position: Tween<Offset>(
            begin: const Offset(-1, 0),
            end: Offset.zero,
          ).animate(animation),
          child: child,
        );
      }
      case PageTransition.SCALE : {
        return ScaleTransition(
          scale: Tween<double>(begin: 0.0, end: 1.0,).animate(
            CurvedAnimation(
              parent: animation,
              curve: Curves.fastOutSlowIn,
            ),
          ),
          child: child,
        );
      }
      case PageTransition.FADE : {
        return FadeTransition(
          opacity: animation,
          child: child,
        );
      }
      default: {
        return FadeTransition(
          opacity: animation,
          child: child,
        );
      }
    }
  }

  static NUIDialog showNUIDialogByItem({@required BuildContext context, @required NUIDialogItem item}){
    return showNUIDialog(context: context, content: item.content, barrierColor: item.barrierColor, barrierLabel: item.barrierLabel, dismissible: item.dismissible, opacity: item.opacity, alignment: item.alignment, transition: item.transition, useSafeArea: item.useSafeArea, transitionDuration: item.transitionDuration, onDismiss: item.onDismiss);
  }

  static NUIDialog showNUIDialog({@required BuildContext context, String barrierLabel, bool dismissible:true, Color barrierColor, double opacity: 0.8, @required DialogBuilder content, Alignment alignment:Alignment.center, PageTransition transition, bool useSafeArea: true, Duration transitionDuration, Function onDismiss}){
    NUIDialog dialog = NUIDialog._builder(content: content, label: barrierLabel, dismiss: (Function innerDismiss){
      log("NUIDialog -> Dialog dismiss not initiated yet");
    });
    try {
      showGeneralDialog(
          barrierLabel: barrierLabel ?? "NUIDialog",
          barrierColor: barrierColor ?? Colors.black.withOpacity(opacity ?? 0.8),
          barrierDismissible: dismissible ?? true,
          transitionDuration: transitionDuration ?? Duration(milliseconds: 250),
          context: context,
          pageBuilder: (context, animation, secondaryAnimation) {
            dialog.dismiss = (Function innerDismiss) {
              log("NUIDialog -> Dismissing dialog ... ");
              Navigator.pop(context);
              if (transitionDuration != null) {
                NUIAsync.delay(transitionDuration, () {
                  if (onDismiss != null) {
                    onDismiss();
                  }
                  innerDismiss();
                });
              }
              else {
                if (onDismiss != null) {
                  onDismiss();
                }
                innerDismiss();
              }
            };
            return Align(
              alignment: alignment ?? Alignment.center,
              child: content(context),
            );
          },
          transitionBuilder: (context, animation, secondaryAnimation, child) {
            return _getTransition(
                context, content(context), transition: transition,
                animation: animation,
                secondaryAnimation: secondaryAnimation,
                child: child);
          }
      );
    }catch(e){

    }

    return dialog;
  }
}

class NUIDialogWidget extends StatefulWidget {
  NUIDialogWidget({@required this.content, this.backgroundColor:NUIColors.NUITransparent, this.elevation:0, Key key}): super(key : key);
  final Widget content;
  final double elevation;
  final Color backgroundColor;
  @override
  _NUIDialogWidgetState createState() => _NUIDialogWidgetState();
}

class _NUIDialogWidgetState extends State<NUIDialogWidget> {
  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(0)),
      elevation: widget.elevation,
      backgroundColor: widget.backgroundColor,
      child: widget.content,
    );
  }
}
